function Ma = isenMapp0(pr,k)
% isenMapp0  Mach number as fcn of pressure ratio p/p0 for isentropic
%            compressible flow
%
% Synopsis:  Ma = isenMapp0(pr)
%            Ma = isenMapp0(pr,k)
%
% Input:   pr = p/p0, pressure ratio
%          k  = (optional) specific heat ratio;  Default:  k = 1.4
%
% Output:  Ma = Mach number

if nargin<2,  k = 1.4;  end   %  default material is air

Ma = sqrt((2/(k-1))*(pr.^((1-k)/k) - 1));
