function Ma = isenMarr0(rr,k)
% isenMarr0  Mach number as fcn of density ratio rho/rho0 for isentropic
%            compressible flow
%
% Synopsis:  Ma = isenMarr0(pr)
%            Ma = isenMarr0(pr,k)
%
% Input:   rr = rho/rho0, density ratio
%          k  = (optional) specific heat ratio;  Default:  k = 1.4
%
% Output:  Ma = Mach number

if nargin<2,  k = 1.4;  end   %  default material is air

Ma = sqrt(2/(k-1))*(rr.^(1-k) - 1);
